@@ -2,8 +2,8 @@ use crate::components::Component;
 use crate::utils::{ChangeTicks, Ticks};
 use std::ops::{Deref, DerefMut};
 
-/// Type returned by mutable queries. Updates the component's `ChangeTicks` when
-/// the component is mutated.
+/// Type returned by iterators over `CompMut`s. Updates the component's
+/// `ChangeTicks` when the component is mutated.
 pub struct ComponentRefMut<'a, T>
 where
     T: Component,
@@ -17,9 +17,7 @@ impl<'a, T> ComponentRefMut<'a, T>
 where
     T: Component,
 {
-    /// Creates a new `ComponentRefMut`which updates the provided `ChangeTicks`
-    /// when `deref_mut` is called.
-    pub fn new(component: &'a mut T, ticks: &'a mut ChangeTicks, world_tick: Ticks) -> Self {
+    pub(crate) fn new(component: &'a mut T, ticks: &'a mut ChangeTicks, world_tick: Ticks) -> Self {
         Self {
             component,
             ticks,
@@ -34,6 +32,7 @@ where
 {
     type Target = T;
 
+    #[inline]
     fn deref(&self) -> &Self::Target {
         self.component
     }
@@ -43,6 +42,7 @@ impl<T> DerefMut for ComponentRefMut<'_, T>
 where
     T: Component,
 {
+    #[inline]
     fn deref_mut(&mut self) -> &mut Self::Target {
         self.ticks.tick_mutated = self.world_tick;
         self.component
