@@ -7,6 +7,7 @@ pub trait QueryElementFilter<T>
 where
     T: Component,
 {
+    /// Returns `true` if the component and ticks match the filter.
     fn matches(
         &self,
         component: &T,
@@ -118,7 +119,7 @@ pub fn contains<'a, E>(element: E) -> Filter<Contains, E>
 where
     E: UnfilteredQueryElement<'a>,
 {
-    Filter::new(Contains, element)
+    Filter::new(element, Contains)
 }
 
 /// Creates a new `Filter` that ony matches newly added components.
@@ -126,7 +127,7 @@ pub fn added<'a, E>(element: E) -> Filter<Added, E>
 where
     E: UnfilteredQueryElement<'a>,
 {
-    Filter::new(Added, element)
+    Filter::new(element, Added)
 }
 
 /// Creates a new `Filter` that ony matches mutated components.
@@ -134,7 +135,7 @@ pub fn mutated<'a, E>(element: E) -> Filter<Mutated, E>
 where
     E: UnfilteredQueryElement<'a>,
 {
-    Filter::new(Mutated, element)
+    Filter::new(element, Mutated)
 }
 
 /// Creates a new `Filter` that ony matches newly added or mutated components.
@@ -142,5 +143,5 @@ pub fn changed<'a, E>(element: E) -> Filter<Changed, E>
 where
     E: UnfilteredQueryElement<'a>,
 {
-    Filter::new(Changed, element)
+    Filter::new(element, Changed)
 }
