@@ -81,7 +81,7 @@ impl Dispatcher {
 
     /// Adds the required component storages to the `World` to avoid
     /// having to add them manually via `World::register`.
-    pub fn set_up(&self, world: &mut World) {
+    pub fn register_storages(&self, world: &mut World) {
         for step in self.steps.iter() {
             match step {
                 Step::RunSystems(systems) => {
@@ -146,11 +146,11 @@ impl Dispatcher {
                     run_local_fns(systems, world, &mut errors);
                 }
                 Step::FlushCommands => {
-                    world.entities.maintain();
+                    world.maintain();
 
-                    for command in self.command_buffers.drain() {
-                        command(world);
-                    }
+                    self.command_buffers
+                        .drain()
+                        .for_each(|command| command(world));
                 }
             }
         }
@@ -207,9 +207,11 @@ impl Dispatcher {
                     run_local_fns(systems, world, &mut errors);
                 }
                 Step::FlushCommands => {
-                    for command in self.command_buffers.drain() {
-                        command(world);
-                    }
+                    world.maintain();
+
+                    self.command_buffers
+                        .drain()
+                        .for_each(|command| command(world));
                 }
             }
         }
@@ -223,8 +225,8 @@ impl Dispatcher {
         }
     }
 
-    /// Get the maximum number of systems which can run concurrently.
-    /// Can be used to set up the number of threads in the `rayon::ThreadPool`.
+    /// Returns the maximum number of systems that can run concurrently.
+    /// Can be used to set the number of threads in the `rayon::ThreadPool`.
     pub fn max_concurrecy(&self) -> usize {
         let mut max_concurrecy = 1;
 
@@ -346,9 +348,7 @@ fn run_systems_seq<S>(
     S: Runnable,
 {
     let registry = unsafe { Registry::new(world, command_buffers, change_tick) };
-
     let new_errors = systems.iter_mut().flat_map(|sys| sys.run(&registry).err());
-
     errors.extend(new_errors);
 }
 
