@@ -31,11 +31,11 @@ where
 
     fn borrow(world: &'a World, change_tick: Ticks) -> Self::Item {
         let (storage, info) = world
-            .storages
+            .component_storages()
             .borrow_with_info(&TypeId::of::<T>())
             .unwrap_or_else(|| panic_missing_comp::<T>());
 
-        unsafe { Comp::new(storage, info, world.tick.get(), change_tick) }
+        unsafe { Comp::new(storage, info, world.tick(), change_tick) }
     }
 }
 
@@ -47,11 +47,11 @@ where
 
     fn borrow(world: &'a World, change_tick: Ticks) -> Self::Item {
         let (storage, info) = world
-            .storages
+            .component_storages()
             .borrow_with_info_mut(&TypeId::of::<T>())
             .unwrap_or_else(|| panic_missing_comp::<T>());
 
-        unsafe { CompMut::new(storage, info, world.tick.get(), change_tick) }
+        unsafe { CompMut::new(storage, info, world.tick(), change_tick) }
     }
 }
 
@@ -62,12 +62,11 @@ where
     type Item = Res<'a, T>;
 
     fn borrow(world: &'a World, change_tick: Ticks) -> Self::Item {
-        let cell = world
-            .resources
+        world
+            .resource_storage()
             .borrow(&TypeId::of::<T>())
-            .unwrap_or_else(|| panic_missing_res::<T>());
-
-        unsafe { Res::new(cell, world.tick.get(), change_tick) }
+            .map(|cell| unsafe { Res::new(cell, world.tick(), change_tick) })
+            .unwrap_or_else(|| panic_missing_res::<T>())
     }
 }
 
@@ -78,12 +77,39 @@ where
     type Item = ResMut<'a, T>;
 
     fn borrow(world: &'a World, change_tick: Ticks) -> Self::Item {
-        let cell = world
-            .resources
+        world
+            .resource_storage()
             .borrow_mut(&TypeId::of::<T>())
-            .unwrap_or_else(|| panic_missing_res::<T>());
+            .map(|cell| unsafe { ResMut::new(cell, world.tick(), change_tick) })
+            .unwrap_or_else(|| panic_missing_res::<T>())
+    }
+}
 
-        unsafe { ResMut::new(cell, world.tick.get(), change_tick) }
+impl<'a, 'b, T> BorrowWorld<'a> for Option<Res<'b, T>>
+where
+    T: Resource,
+{
+    type Item = Option<Res<'a, T>>;
+
+    fn borrow(world: &'a World, change_tick: Ticks) -> Self::Item {
+        world
+            .resource_storage()
+            .borrow(&TypeId::of::<T>())
+            .map(|cell| unsafe { Res::new(cell, world.tick(), change_tick) })
+    }
+}
+
+impl<'a, 'b, T> BorrowWorld<'a> for Option<ResMut<'b, T>>
+where
+    T: Resource,
+{
+    type Item = Option<ResMut<'a, T>>;
+
+    fn borrow(world: &'a World, change_tick: Ticks) -> Self::Item {
+        world
+            .resource_storage()
+            .borrow_mut(&TypeId::of::<T>())
+            .map(|cell| unsafe { ResMut::new(cell, world.tick(), change_tick) })
     }
 }
 
